@@ -11,7 +11,7 @@ use HTTP::Request();
 use HTTP::Response();
 use POSIX();
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 sub _CHUNK_SIZE                { return 4096 }
 sub _FILE_READ_SIZE            { return 8192 }
@@ -729,7 +729,7 @@ Net::ICAP::Client - A client implementation of the ICAP (RFC 3507) protocol
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =head1 SYNOPSIS
 
@@ -775,27 +775,27 @@ $icap->agent() accepts an optional User Agent string and returns the current Use
 
 =head2 server_allows_204
 
-$icap->server_allows_204() returns true if the remote ICAP server can return a 204 (No modification needed) response.  This method requires that the OPTIONS method has been sent to the remote server within the TTL window advertised by the remote server.
+$icap->server_allows_204() returns true if the remote ICAP server can return a 204 (No modification needed) response.  This method will issue an OPTIONS call to the remote server unless another OPTIONS call has been sent in the last L<ttl|"ttl"> seconds.
 
 =head2 is_tag
 
-$icap->is_tag() returns the value of the remote ICAP server's L<ISTag|https://tools.ietf.org/html/rfc3507#section-4.7> header.  This method requires that the OPTIONS method has been sent to the remote server within the TTL window advertised by the remote server.
+$icap->is_tag() returns the value of the remote ICAP server's L<ISTag|https://tools.ietf.org/html/rfc3507#section-4.7> header.  This method will issue an OPTIONS call to the remote server unless another OPTIONS call has been sent in the last L<ttl|"ttl"> seconds.
 
 =head2 service
 
-$icap->service() returns the value of the remote ICAP server's L<Service|https://tools.ietf.org/html/rfc3507#section-4.10.2> header.  This method requires that the OPTIONS method has been sent to the remote server within the TTL window advertised by the remote server.
+$icap->service() returns the value of the remote ICAP server's L<Service|https://tools.ietf.org/html/rfc3507#section-4.10.2> header.  This method will issue an OPTIONS call to the remote server unless another OPTIONS call has been sent in the last L<ttl|"ttl"> seconds.
 
 =head2 ttl
 
-$icap->ttl() returns the value of the remote ICAP server's L<Options-TTL|https://tools.ietf.org/html/rfc3507#section-4.10.2> header.  This method requires that the OPTIONS method has been sent to the remote server within the TTL window advertised by the remote server.
+$icap->ttl() returns the value of the remote ICAP server's L<Options-TTL|https://tools.ietf.org/html/rfc3507#section-4.10.2> header.  This method will issue an OPTIONS call to the remote server unless another OPTIONS call has been sent in the last L<ttl|"ttl"> seconds.
 
 =head2 max_connections
 
-$icap->max_connections() returns the value of the remote ICAP server's L<Max-Connections|https://tools.ietf.org/html/rfc3507#section-4.10.2> header.  This method requires that the OPTIONS method has been sent to the remote server within the TTL window advertised by the remote server.
+$icap->max_connections() returns the value of the remote ICAP server's L<Max-Connections|https://tools.ietf.org/html/rfc3507#section-4.10.2> header.  This method will issue an OPTIONS call to the remote server unless another OPTIONS call has been sent in the last L<ttl|"ttl"> seconds.
 
 =head2 preview_size
 
-$icap->preview_size() returns the value of the remote ICAP server's L<Preview|https://tools.ietf.org/html/rfc3507#section-4.10.2> header.  This method requires that the OPTIONS method has been sent to the remote server within the TTL window advertised by the remote server.
+$icap->preview_size() returns the value of the remote ICAP server's L<Preview|https://tools.ietf.org/html/rfc3507#section-4.10.2> header.  This method will issue an OPTIONS call to the remote server unless another OPTIONS call has been sent in the last L<ttl|"ttl"> seconds.
 
 =head2 uri
 
